| addPlotStatsSamples | R Documentation |
Use ggpubr to add statistics to samples or plot
addPlotStatsSamples(
p,
comp.group,
metadata,
h.adj = 0.05,
exact = FALSE,
second.comp.group
)
p |
Plot to add statistics to. |
comp.group |
Metadata column used as the primary grouping variable. Must match a column name of metadata (default = self$comp.group). |
metadata |
Metadata for samples. |
h.adj |
Relative vertical offset for displaying the statistical test p-value in the plot, expressed as a % of the maximum y-value (default = 0.05). |
exact |
Whether to display exact p-values instead of rounded values (default = FALSE). |
second.comp.group |
Second comparison metric. |
ggplot2 object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.